@@ -77,6 +77,10 @@ ALTER EXTENSION pgtap ADD FUNCTION lives_ok ( TEXT, TEXT );
 ALTER EXTENSION pgtap ADD FUNCTION lives_ok ( TEXT );
 ALTER EXTENSION pgtap ADD FUNCTION performs_ok ( TEXT, NUMERIC, TEXT );
 ALTER EXTENSION pgtap ADD FUNCTION performs_ok ( TEXT, NUMERIC );
+ALTER EXTENSION pgtap ADD FUNCTION performs_within ( TEXT, NUMERIC, NUMERIC, INT, TEXT );
+ALTER EXTENSION pgtap ADD FUNCTION performs_within ( TEXT, NUMERIC, NUMERIC, TEXT );
+ALTER EXTENSION pgtap ADD FUNCTION performs_within ( TEXT, NUMERIC, NUMERIC, INT );
+ALTER EXTENSION pgtap ADD FUNCTION performs_within ( TEXT, NUMERIC, NUMERIC );
 ALTER EXTENSION pgtap ADD FUNCTION _rexists ( CHAR, NAME, NAME );
 ALTER EXTENSION pgtap ADD FUNCTION _rexists ( CHAR, NAME );
 ALTER EXTENSION pgtap ADD FUNCTION has_table ( NAME, NAME, TEXT );
