@@ -1,7 +1,7 @@
 \unset ECHO
 \i test/setup.sql
 
-SELECT plan(228);
+SELECT plan(243);
 --SELECT * from no_plan();
 
 CREATE TYPE public."myType" AS (
@@ -23,6 +23,11 @@ CREATE TABLE public.sometab(
     crole   TEXT DEFAULT CURRENT_ROLE,
     csch    TEXT DEFAULT CURRENT_SCHEMA,
     ccat    TEXT DEFAULT CURRENT_CATALOG,
+    cdate   DATE DEFAULT CURRENT_DATE,
+    ctime   TIMETZ DEFAULT CURRENT_TIME,
+    ctstz   TIMESTAMPTZ DEFAULT CURRENT_TIMESTAMP,
+    ltime   TIME DEFAULT LOCALTIME,
+    ltstz   TIMESTAMPTZ DEFAULT LOCALTIMESTAMP,
     plain   INTEGER,
     camel   "myType"
 );
@@ -511,117 +516,47 @@ SELECT * FROM check_test(
 );
 
 -- Make sure it works with a NULL default.
-CREATE OR REPLACE FUNCTION versiontests () RETURNS SETOF TEXT AS $$
-DECLARE
-    tap record;
-BEGIN
-    IF pg_version_num() < 80300 THEN
-        -- Before 8.3, have to cast to text.
-        FOR tap IN SELECT * FROM check_test(
-            col_default_is( 'sometab', 'myNum', 24::text ),
-            true,
-            'col_default_is( tab, col, int )',
-            'Column sometab."myNum" should default to ''24''',
-            ''
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
+SELECT * FROM check_test(
+    col_default_is( 'sometab', 'myNum', 24 ),
+    true,
+    'col_default_is( tab, col, int )',
+    'Column sometab."myNum" should default to ''24''',
+    ''
+);
 
-        -- Before 8.3, DEFAULT NULL was ignored.
-        FOR tap IN SELECT * FROM fakeout(
-            true, 'col_default_is( tab, col, NULL, desc )'
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
+        -- We can handle DEFAULT NULL correctly.
+SELECT * FROM check_test(
+    col_default_is( 'sometab', 'numb', NULL::numeric, 'desc' ),
+    true,
+    'col_default_is( tab, col, NULL, desc )',
+    'desc',
+    ''
+);
 
-        FOR tap IN SELECT * FROM fakeout(
-            true, 'col_default_is( tab, col, NULL )'
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
+SELECT * FROM check_test(
+    col_default_is( 'sometab', 'numb', NULL::numeric ),
+    true,
+    'col_default_is( tab, col, NULL )',
+    'Column sometab.numb should default to NULL',
+    ''
+);
 
-        -- Make sure that it fails when there is no default.
-        -- Before 8.3, must cast values to text
-        FOR tap IN SELECT * FROM check_test(
-            col_default_is( 'sometab', 'plain', 1::text, 'desc' ),
-            false,
-            'col_default_is( tab, col, bogus, desc )',
-            'desc',
-            '    Column sometab.plain has no default'
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
+-- Make sure that it fails when there is no default.
+SELECT * FROM check_test(
+    col_default_is( 'sometab', 'plain', 1, 'desc' ),
+    false,
+    'col_default_is( tab, col, bogus, desc )',
+    'desc',
+    '    Column sometab.plain has no default'
+);
 
-        FOR tap IN SELECT * FROM check_test(
-            col_default_is( 'sometab', 'plain', 1::text ),
-            false,
-            'col_default_is( tab, col, bogus )',
-            'Column sometab.plain should default to ''1''',
-            '    Column sometab.plain has no default'
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
-
-    ELSE
-        -- In 8.3 and later, can just use the raw value.
-        FOR tap IN SELECT * FROM check_test(
-            col_default_is( 'sometab', 'myNum', 24 ),
-            true,
-            'col_default_is( tab, col, int )',
-            'Column sometab."myNum" should default to ''24''',
-            ''
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
-
-        -- In 8.3 and later, we can handle DEFAULT NULL correctly.
-        FOR tap IN SELECT * FROM check_test(
-            col_default_is( 'sometab', 'numb', NULL::numeric, 'desc' ),
-            true,
-            'col_default_is( tab, col, NULL, desc )',
-            'desc',
-            ''
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
-
-        FOR tap IN SELECT * FROM check_test(
-            col_default_is( 'sometab', 'numb', NULL::numeric ),
-            true,
-            'col_default_is( tab, col, NULL )',
-            'Column sometab.numb should default to NULL',
-            ''
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
-
-        -- Make sure that it fails when there is no default.
-        -- In 8.3 and later, can just use raw values.
-        FOR tap IN SELECT * FROM check_test(
-            col_default_is( 'sometab', 'plain', 1, 'desc' ),
-            false,
-            'col_default_is( tab, col, bogus, desc )',
-            'desc',
-            '    Column sometab.plain has no default'
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
-
-        FOR tap IN SELECT * FROM check_test(
-            col_default_is( 'sometab', 'plain', 1 ),
-            false,
-            'col_default_is( tab, col, bogus )',
-            'Column sometab.plain should default to ''1''',
-            '    Column sometab.plain has no default'
-        ) AS a(b) LOOP
-            RETURN NEXT tap.b;
-        END LOOP;
-
-    END IF;
-    RETURN;
-END;
-$$ LANGUAGE plpgsql;
-SELECT * FROM versiontests();
+SELECT * FROM check_test(
+    col_default_is( 'sometab', 'plain', 1 ),
+    false,
+    'col_default_is( tab, col, bogus )',
+    'Column sometab.plain should default to ''1''',
+    '    Column sometab.plain has no default'
+);
 
 -- Make sure that it works when the default is an expression.
 SELECT * FROM check_test(
@@ -693,16 +628,16 @@ SELECT * FROM check_test(
 -- Make sure that it works when the default is a reserved SQL expression.
 CREATE OR REPLACE FUNCTION ckreserve() RETURNS SETOF TEXT LANGUAGE PLPGSQL AS $$
 DECLARE
-    funcs text[] := '{CURRENT_CATALOG,CURRENT_ROLE,CURRENT_SCHEMA,CURRENT_USER,SESSION_USER,USER}';
-    cols  TEXT[] := '{ccat,crole,csch,cuser,suser,auser}';
+    funcs text[] := '{CURRENT_CATALOG,CURRENT_ROLE,CURRENT_SCHEMA,CURRENT_USER,SESSION_USER,USER,CURRENT_DATE,CURRENT_TIME,CURRENT_TIMESTAMP,LOCALTIME,LOCALTIMESTAMP}';
+    cols  TEXT[] := '{ccat,crole,csch,cuser,suser,auser,cdate,ctime,ctstz,ltime,ltstz}';
     exp   TEXT[] := funcs;
     tap           record;
     last_index    INTEGER;
 BEGIN
     last_index := array_upper(funcs, 1);
     IF pg_version_num() < 100000 THEN
-       -- Prior to PostgreSQL 10, these wer functions rendered with paretheses.
-       exp := ARRAY['current_database()','"current_user"()','"current_schema"()','"current_user"()','"session_user"()','"current_user"()'];
+       -- Prior to PostgreSQL 10, these were functions rendered with paretheses or as casts.
+       exp := ARRAY['current_database()','"current_user"()','"current_schema"()','"current_user"()','"session_user"()','"current_user"()','(''now''::text)::date','(''now''::text)::time with time zone','now()','(''now''::text)::time without time zone','(''now''::text)::timestamp without time zone'];
     END IF;
 
     FOR i IN 1..last_index LOOP
