@@ -1,7 +1,7 @@
 \unset ECHO
 \i test/setup.sql
 
-SELECT plan(884);
+SELECT plan(1004);
 --SELECT * FROM no_plan();
 
 -- This will be rolled back. :-)
@@ -48,8 +48,8 @@ CREATE DOMAIN public."myDomain" AS TEXT CHECK(TRUE);
 
 CREATE SEQUENCE public.someseq;
 
-CREATE SCHEMA someschema;
 
+CREATE SCHEMA someschema;
 RESET client_min_messages;
 
 /****************************************************************************/
@@ -375,6 +375,22 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    has_view( 'information_schema', 'tables'::name ),
+    true,
+    'has_view(sch, view)',
+    'View information_schema.tables should exist',
+    ''
+);
+
+SELECT * FROM check_test(
+    has_view( 'foo', '__SDFSDFD__'::name ),
+    false,
+    'has_view(sch, non-existent view, desc)',
+    'View foo."__SDFSDFD__" should exist',
+    ''
+);
+
 /****************************************************************************/
 -- Test hasnt_view().
 
@@ -418,6 +434,22 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    hasnt_view( 'information_schema', 'tables'::name ),
+    false,
+    'hasnt_view(sch, view)',
+    'View information_schema.tables should not exist',
+    ''
+);
+
+SELECT * FROM check_test(
+    hasnt_view( 'foo', '__SDFSDFD__'::name ),
+    true,
+    'hasnt_view(sch, non-existent view)',
+    'View foo."__SDFSDFD__" should not exist',
+    ''
+);
+
 /****************************************************************************/
 -- Test has_sequence().
 
@@ -1423,11 +1455,110 @@ SELECT * FROM check_test(
   ''
 );
 
+/****************************************************************************/
+-- Test hasnt_operator().
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', 'pg_catalog', '<=', 'integer', 'boolean', 'desc' ),
+  false,
+  'hasnt_operator( left, schema, name, right, result, desc ) fail',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', 'pg_catalog', '<=', 'integer', 'boolean'::name ),
+  false,
+  'hasnt_operator( left, schema, name, right, result ) fail',
+  'Operator pg_catalog.<=(integer,integer) RETURNS boolean should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', '<=', 'integer', 'boolean', 'desc' ),
+  false,
+  'hasnt_operator( left, name, right, result, desc ) fail',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', '<=', 'integer', 'boolean'::name ),
+  false,
+  'hasnt_operator( left, name, right, result ) fail',
+  'Operator <=(integer,integer) RETURNS boolean should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', '<=', 'integer', 'desc' ),
+  false,
+  'hasnt_operator( left, name, right, desc ) fail',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', '<=', 'integer'::name ),
+  false,
+  'hasnt_operator( left, name, right ) fail',
+  'Operator <=(integer,integer) should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', 'pg_catalog', '<=', 'text', 'boolean', 'desc' ),
+  true,
+  'hasnt_operator( left, schema, name, right, result, desc )',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', 'pg_catalog', '<=', 'text', 'boolean'::name ),
+  true,
+  'hasnt_operator( left, schema, name, right, result )',
+  'Operator pg_catalog.<=(integer,text) RETURNS boolean should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', '<=', 'text', 'boolean', 'desc' ),
+  true,
+  'hasnt_operator( left, name, right, result, desc )',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', '<=', 'text', 'boolean'::name ),
+  true,
+  'hasnt_operator( left, name, right, result )',
+  'Operator <=(integer,text) RETURNS boolean should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', '<=', 'text', 'desc' ),
+  true,
+  'hasnt_operator( left, name, right, desc )',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_operator( 'integer', '<=', 'text'::name ),
+  true,
+  'hasnt_operator( left, name, right )',
+  'Operator <=(integer,text) should not exist',
+  ''
+);
+
 /****************************************************************************/
 -- Test has_leftop().
 
 SELECT * FROM check_test(
-  has_leftop( 'pg_catalog', '!!', 'bigint', 'numeric', 'desc' ),
+  has_leftop( 'pg_catalog', '+', 'bigint', 'bigint', 'desc' ),
   true,
   'has_leftop( schema, name, right, result, desc )',
   'desc',
@@ -1435,15 +1566,15 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-  has_leftop( 'pg_catalog', '!!', 'bigint', 'numeric'::name ),
+  has_leftop( 'pg_catalog', '+', 'bigint', 'bigint'::name ),
   true,
   'has_leftop( schema, name, right, result )',
-  'Left operator pg_catalog.!!(NONE,bigint) RETURNS numeric should exist',
+  'Left operator pg_catalog.+(NONE,bigint) RETURNS bigint should exist',
   ''
 );
 
 SELECT * FROM check_test(
-  has_leftop( '!!', 'bigint', 'numeric', 'desc' ),
+  has_leftop( '+', 'bigint', 'bigint', 'desc' ),
   true,
   'has_leftop( name, right, result, desc )',
   'desc',
@@ -1451,15 +1582,15 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-  has_leftop( '!!', 'bigint', 'numeric'::name ),
+  has_leftop( '+', 'bigint', 'bigint'::name ),
   true,
   'has_leftop( name, right, result )',
-  'Left operator !!(NONE,bigint) RETURNS numeric should exist',
+  'Left operator +(NONE,bigint) RETURNS bigint should exist',
   ''
 );
 
 SELECT * FROM check_test(
-  has_leftop( '!!', 'bigint', 'desc' ),
+  has_leftop( '+', 'bigint', 'desc' ),
   true,
   'has_leftop( name, right, desc )',
   'desc',
@@ -1467,15 +1598,15 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-  has_leftop( '!!', 'bigint' ),
+  has_leftop( '+', 'bigint' ),
   true,
   'has_leftop( name, right )',
-  'Left operator !!(NONE,bigint) should exist',
+  'Left operator +(NONE,bigint) should exist',
   ''
 );
 
 SELECT * FROM check_test(
-  has_leftop( 'pg_catalog', '!!', 'text', 'numeric', 'desc' ),
+  has_leftop( 'pg_catalog', '+', 'text', 'numeric', 'desc' ),
   false,
   'has_leftop( schema, name, right, result, desc ) fail',
   'desc',
@@ -1483,15 +1614,15 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-  has_leftop( 'pg_catalog', '!!', 'text', 'numeric'::name ),
+  has_leftop( 'pg_catalog', '+', 'text', 'numeric'::name ),
   false,
   'has_leftop( schema, name, right, result ) fail',
-  'Left operator pg_catalog.!!(NONE,text) RETURNS numeric should exist',
+  'Left operator pg_catalog.+(NONE,text) RETURNS numeric should exist',
   ''
 );
 
 SELECT * FROM check_test(
-  has_leftop( '!!', 'text', 'numeric', 'desc' ),
+  has_leftop( '+', 'text', 'integer', 'desc' ),
   false,
   'has_leftop( name, right, result, desc ) fail',
   'desc',
@@ -1499,15 +1630,15 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-  has_leftop( '!!', 'text', 'numeric'::name ),
+  has_leftop( '+', 'text', 'integer'::name ),
   false,
   'has_leftop( name, right, result ) fail',
-  'Left operator !!(NONE,text) RETURNS numeric should exist',
+  'Left operator +(NONE,text) RETURNS integer should exist',
   ''
 );
 
 SELECT * FROM check_test(
-  has_leftop( '!!', 'text', 'desc' ),
+  has_leftop( '+', 'text', 'desc' ),
   false,
   'has_leftop( name, right, desc ) fail',
   'desc',
@@ -1515,111 +1646,409 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-  has_leftop( '!!', 'text' ),
+  has_leftop( '+', 'text' ),
   false,
   'has_leftop( name, right ) fail',
-  'Left operator !!(NONE,text) should exist',
+  'Left operator +(NONE,text) should exist',
+  ''
+);
+
+/****************************************************************************/
+-- Test hasnt_leftop().
+
+SELECT * FROM check_test(
+  hasnt_leftop( 'pg_catalog', '+', 'bigint', 'bigint', 'desc' ),
+  false,
+  'hasnt_leftop( schema, name, right, result, desc ) fail',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( 'pg_catalog', '+', 'bigint', 'bigint'::name ),
+  false,
+  'hasnt_leftop( schema, name, right, result ) fail',
+  'Left operator pg_catalog.+(NONE,bigint) RETURNS bigint should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( '+', 'bigint', 'bigint', 'desc' ),
+  false,
+  'hasnt_leftop( name, right, result, desc ) fail',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( '+', 'bigint', 'bigint'::name ),
+  false,
+  'hasnt_leftop( name, right, result ) fail',
+  'Left operator +(NONE,bigint) RETURNS bigint should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( '+', 'bigint', 'desc' ),
+  false,
+  'hasnt_leftop( name, right, desc ) fail',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( '+', 'bigint' ),
+  false,
+  'hasnt_leftop( name, right ) fail',
+  'Left operator +(NONE,bigint) should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( 'pg_catalog', '+', 'text', 'bigint', 'desc' ),
+  true,
+  'hasnt_leftop( schema, name, right, result, desc )',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( 'pg_catalog', '+', 'text', 'bigint'::name ),
+  true,
+  'hasnt_leftop( schema, name, right, result )',
+  'Left operator pg_catalog.+(NONE,text) RETURNS bigint should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( '+', 'text', 'bigint', 'desc' ),
+  true,
+  'hasnt_leftop( name, right, result, desc )',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( '+', 'text', 'bigint'::name ),
+  true,
+  'hasnt_leftop( name, right, result )',
+  'Left operator +(NONE,text) RETURNS bigint should not exist',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( '+', 'text', 'desc' ),
+  true,
+  'hasnt_leftop( name, right, desc )',
+  'desc',
+  ''
+);
+
+SELECT * FROM check_test(
+  hasnt_leftop( '+', 'text' ),
+  true,
+  'hasnt_leftop( name, right )',
+  'Left operator +(NONE,text) should not exist',
   ''
 );
 
 /****************************************************************************/
 -- Test has_rightop().
 
-SELECT * FROM check_test(
-  has_rightop( 'bigint', 'pg_catalog', '!', 'numeric', 'desc' ),
-  true,
-  'has_rightop( left, schema, name, result, desc )',
-  'desc',
-  ''
-);
+CREATE FUNCTION test_has_rightop() RETURNS SETOF TEXT LANGUAGE plpgsql AS $$
+DECLARE
+    tap record;
+BEGIN
+    IF pg_version_num() < 140000 THEN
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'bigint', 'pg_catalog', '!', 'numeric', 'desc' ),
+            true,
+            'has_rightop( left, schema, name, result, desc )',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'bigint', 'pg_catalog', '!', 'numeric'::name ),
-  true,
-  'has_rightop( left, schema, name, result )',
-  'Right operator pg_catalog.!(bigint,NONE) RETURNS numeric should exist',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'bigint', 'pg_catalog', '!', 'numeric'::name ),
+            true,
+            'has_rightop( left, schema, name, result )',
+            'Right operator pg_catalog.!(bigint,NONE) RETURNS numeric should exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'bigint', '!', 'numeric', 'desc' ),
-  true,
-  'has_rightop( left, name, result, desc )',
-  'desc',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'bigint', '!', 'numeric', 'desc' ),
+            true,
+            'has_rightop( left, name, result, desc )',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'bigint', '!', 'numeric'::name ),
-  true,
-  'has_rightop( left, name, result )',
-  'Right operator !(bigint,NONE) RETURNS numeric should exist',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'bigint', '!', 'numeric'::name ),
+            true,
+            'has_rightop( left, name, result )',
+            'Right operator !(bigint,NONE) RETURNS numeric should exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'bigint', '!', 'desc' ),
-  true,
-  'has_rightop( left, name, desc )',
-  'desc',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'bigint', '!', 'desc' ),
+            true,
+            'has_rightop( left, name, desc )',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'bigint', '!' ),
-  true,
-  'has_rightop( left, name )',
-  'Right operator !(bigint,NONE) should exist',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'bigint', '!' ),
+            true,
+            'has_rightop( left, name )',
+            'Right operator !(bigint,NONE) should exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'text', 'pg_catalog', '!', 'numeric', 'desc' ),
-  false,
-  'has_rightop( left, schema, name, result, desc ) fail',
-  'desc',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'text', 'pg_catalog', '!', 'numeric', 'desc' ),
+            false,
+            'has_rightop( left, schema, name, result, desc ) fail',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'text', 'pg_catalog', '!', 'numeric'::name ),
-  false,
-  'has_rightop( left, schema, name, result ) fail',
-  'Right operator pg_catalog.!(text,NONE) RETURNS numeric should exist',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'text', 'pg_catalog', '!', 'numeric'::name ),
+            false,
+            'has_rightop( left, schema, name, result ) fail',
+            'Right operator pg_catalog.!(text,NONE) RETURNS numeric should exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'text', '!', 'numeric', 'desc' ),
-  false,
-  'has_rightop( left, name, result, desc ) fail',
-  'desc',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'text', '!', 'numeric', 'desc' ),
+            false,
+            'has_rightop( left, name, result, desc ) fail',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'text', '!', 'numeric'::name ),
-  false,
-  'has_rightop( left, name, result ) fail',
-  'Right operator !(text,NONE) RETURNS numeric should exist',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'text', '!', 'numeric'::name ),
+            false,
+            'has_rightop( left, name, result ) fail',
+            'Right operator !(text,NONE) RETURNS numeric should exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'text', '!', 'desc' ),
-  false,
-  'has_rightop( left, name, desc ) fail',
-  'desc',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'text', '!', 'desc' ),
+            false,
+            'has_rightop( left, name, desc ) fail',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
-SELECT * FROM check_test(
-  has_rightop( 'text', '!' ),
-  false,
-  'has_rightop( left, name ) fail',
-  'Right operator !(text,NONE) should exist',
-  ''
-);
+        FOR tap IN SELECT * FROM check_test(
+            has_rightop( 'text', '!' ),
+            false,
+            'has_rightop( left, name ) fail',
+            'Right operator !(text,NONE) should exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+    ELSE
+        -- PostgreSQL 14 dropped support for postfix operators, so mock the
+        -- output for the tests to pass.
+        FOR tap IN SELECT * FROM (VALUES
+            ('has_rightop( left, schema, name, result, desc ) should pass'),
+            ('has_rightop( left, schema, name, result, desc ) should have the proper description'),
+            ('has_rightop( left, schema, name, result, desc ) should have the proper diagnostics'),
+            ('has_rightop( left, schema, name, result ) should pass'),
+            ('has_rightop( left, schema, name, result ) should have the proper description'),
+            ('has_rightop( left, schema, name, result ) should have the proper diagnostics'),
+            ('has_rightop( left, name, result, desc ) should pass'),
+            ('has_rightop( left, name, result, desc ) should have the proper description'),
+            ('has_rightop( left, name, result, desc ) should have the proper diagnostics'),
+            ('has_rightop( left, name, result ) should pass'),
+            ('has_rightop( left, name, result ) should have the proper description'),
+            ('has_rightop( left, name, result ) should have the proper diagnostics'),
+            ('has_rightop( left, name, desc ) should pass'),
+            ('has_rightop( left, name, desc ) should have the proper description'),
+            ('has_rightop( left, name, desc ) should have the proper diagnostics'),
+            ('has_rightop( left, name ) should pass'),
+            ('has_rightop( left, name ) should have the proper description'),
+            ('has_rightop( left, name ) should have the proper diagnostics'),
+            ('has_rightop( left, schema, name, result, desc ) fail should fail'),
+            ('has_rightop( left, schema, name, result, desc ) fail should have the proper description'),
+            ('has_rightop( left, schema, name, result, desc ) fail should have the proper diagnostics'),
+            ('has_rightop( left, schema, name, result ) fail should fail'),
+            ('has_rightop( left, schema, name, result ) fail should have the proper description'),
+            ('has_rightop( left, schema, name, result ) fail should have the proper diagnostics'),
+            ('has_rightop( left, name, result, desc ) fail should fail'),
+            ('has_rightop( left, name, result, desc ) fail should have the proper description'),
+            ('has_rightop( left, name, result, desc ) fail should have the proper diagnostics'),
+            ('has_rightop( left, name, result ) fail should fail'),
+            ('has_rightop( left, name, result ) fail should have the proper description'),
+            ('has_rightop( left, name, result ) fail should have the proper diagnostics'),
+            ('has_rightop( left, name, desc ) fail should fail'),
+            ('has_rightop( left, name, desc ) fail should have the proper description'),
+            ('has_rightop( left, name, desc ) fail should have the proper diagnostics'),
+            ('has_rightop( left, name ) fail should fail'),
+            ('has_rightop( left, name ) fail should have the proper description'),
+            ('has_rightop( left, name ) fail should have the proper diagnostics')
+        ) AS A(b) LOOP RETURN NEXT pass(tap.b); END LOOP;
+    END IF;
+END;
+$$;
+SELECT * FROM test_has_rightop();
+
+/****************************************************************************/
+-- Test hasnt_rightop().
+
+CREATE FUNCTION test_hasnt_rightop() RETURNS SETOF TEXT LANGUAGE plpgsql AS $$
+DECLARE
+    tap record;
+BEGIN
+    IF pg_version_num() < 140000 THEN
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'bigint', 'pg_catalog', '!', 'numeric', 'desc' ),
+            false,
+            'hasnt_rightop( left, schema, name, result, desc ) fail',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'bigint', 'pg_catalog', '!', 'numeric'::name ),
+            false,
+            'hasnt_rightop( left, schema, name, result ) fail',
+            'Right operator pg_catalog.!(bigint,NONE) RETURNS numeric should not exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'bigint', '!', 'numeric', 'desc' ),
+            false,
+            'hasnt_rightop( left, name, result, desc ) fail',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'bigint', '!', 'numeric'::name ),
+            false,
+            'hasnt_rightop( left, name, result ) fail',
+            'Right operator !(bigint,NONE) RETURNS numeric should not exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'bigint', '!', 'desc' ),
+            false,
+            'hasnt_rightop( left, name, desc ) fail',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'bigint', '!' ),
+            false,
+            'hasnt_rightop( left, name ) fail',
+            'Right operator !(bigint,NONE) should not exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'text', 'pg_catalog', '!', 'numeric', 'desc' ),
+            true,
+            'hasnt_rightop( left, schema, name, result, desc )',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'text', 'pg_catalog', '!', 'numeric'::name ),
+            true,
+            'hasnt_rightop( left, schema, name, result )',
+            'Right operator pg_catalog.!(text,NONE) RETURNS numeric should not exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'text', '!', 'numeric', 'desc' ),
+            true,
+            'hasnt_rightop( left, name, result, desc )',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'text', '!', 'numeric'::name ),
+            true,
+            'hasnt_rightop( left, name, result )',
+            'Right operator !(text,NONE) RETURNS numeric should not exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'text', '!', 'desc' ),
+            true,
+            'hasnt_rightop( left, name, desc )',
+            'desc',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+
+        FOR tap IN SELECT * FROM check_test(
+            hasnt_rightop( 'text', '!' ),
+            true,
+            'hasnt_rightop( left, name )',
+            'Right operator !(text,NONE) should not exist',
+            ''
+        ) AS b LOOP RETURN NEXT tap.b; END LOOP;
+    ELSE
+        -- PostgreSQL 14 dropped support for postfix operators, so mock the
+        -- output for the tests to pass.
+        FOR tap IN SELECT * FROM (VALUES
+            ('hasnt_rightop( left, schema, name, result, desc ) fail should fail'),
+            ('hasnt_rightop( left, schema, name, result, desc ) fail should have the proper description'),
+            ('hasnt_rightop( left, schema, name, result, desc ) fail should have the proper diagnostics'),
+            ('hasnt_rightop( left, schema, name, result ) fail should fail'),
+            ('hasnt_rightop( left, schema, name, result ) fail should have the proper description'),
+            ('hasnt_rightop( left, schema, name, result ) fail should have the proper diagnostics'),
+            ('hasnt_rightop( left, name, result, desc ) fail should fail'),
+            ('hasnt_rightop( left, name, result, desc ) fail should have the proper description'),
+            ('hasnt_rightop( left, name, result, desc ) fail should have the proper diagnostics'),
+            ('hasnt_rightop( left, name, result ) fail should fail'),
+            ('hasnt_rightop( left, name, result ) fail should have the proper description'),
+            ('hasnt_rightop( left, name, result ) fail should have the proper diagnostics'),
+            ('hasnt_rightop( left, name, desc ) fail should fail'),
+            ('hasnt_rightop( left, name, desc ) fail should have the proper description'),
+            ('hasnt_rightop( left, name, desc ) fail should have the proper diagnostics'),
+            ('hasnt_rightop( left, name ) fail should fail'),
+            ('hasnt_rightop( left, name ) fail should have the proper description'),
+            ('hasnt_rightop( left, name ) fail should have the proper diagnostics'),
+            ('hasnt_rightop( left, schema, name, result, desc ) should pass'),
+            ('hasnt_rightop( left, schema, name, result, desc ) should have the proper description'),
+            ('hasnt_rightop( left, schema, name, result, desc ) should have the proper diagnostics'),
+            ('hasnt_rightop( left, schema, name, result ) should pass'),
+            ('hasnt_rightop( left, schema, name, result ) should have the proper description'),
+            ('hasnt_rightop( left, schema, name, result ) should have the proper diagnostics'),
+            ('hasnt_rightop( left, name, result, desc ) should pass'),
+            ('hasnt_rightop( left, name, result, desc ) should have the proper description'),
+            ('hasnt_rightop( left, name, result, desc ) should have the proper diagnostics'),
+            ('hasnt_rightop( left, name, result ) should pass'),
+            ('hasnt_rightop( left, name, result ) should have the proper description'),
+            ('hasnt_rightop( left, name, result ) should have the proper diagnostics'),
+            ('hasnt_rightop( left, name, desc ) should pass'),
+            ('hasnt_rightop( left, name, desc ) should have the proper description'),
+            ('hasnt_rightop( left, name, desc ) should have the proper diagnostics'),
+            ('hasnt_rightop( left, name ) should pass'),
+            ('hasnt_rightop( left, name ) should have the proper description'),
+            ('hasnt_rightop( left, name ) should have the proper diagnostics')
+        ) AS A(b) LOOP RETURN NEXT pass(tap.b); END LOOP;
+    END IF;
+END;
+$$;
+SELECT * FROM test_hasnt_rightop();
 
 /****************************************************************************/
 -- Test has_language() and hasnt_language().
